@@ -115,17 +115,13 @@ class CaseHandler(object):
         if hgnc_id is None:
             LOG.debug(f"No gene with the HGNC symbol {query_term} found.")
             query["_id"] = {"$in": []}  # No result should be returned by query
+            return
 
         unwind = "$causatives"
         lookup_local = "causatives"
-        lookups_as = "causative_variant"
-        match = "causative_variant.hgnc_ids"
-
         if query_field == "pinned":
             unwind = "$suspects"
             lookup_local = "suspects"
-            lookups_as = "suspect_variant"
-            match = "suspect_variant.hgnc_ids.hgnc_ids"
 
         cases_with_gene_doc = self.case_collection.aggregate(
             [
@@ -135,10 +131,10 @@ class CaseHandler(object):
                         "from": "variant",
                         "localField": lookup_local,
                         "foreignField": "_id",
-                        "as": lookups_as,
+                        "as": "lookup_variant",
                     }
                 },
-                {"$match": {match: hgnc_id}},
+                {"$match": {"lookup_variant.hgnc_ids": hgnc_id}},
                 {"$project": {"_id": 1}},
             ]
         )
@@ -261,6 +257,7 @@ class CaseHandler(object):
         yield_query=False,
         within_days=None,
         assignee=None,
+        verification_pending=None,
     ):
         """Fetches all cases from the backend.
 
@@ -280,11 +277,12 @@ class CaseHandler(object):
             phenotype_terms(bool): Fetch all cases with phenotype
             pinned(bool): Fetch all cases with pinned variants
             name_query(str): Could be hpo term, HPO-group, user, part of display name,
-                             part of inds or part of synopsis
+                             part of ids or part of synopsis
             yield_query(bool): If true, only return mongo query dict for use in
                                 compound querying.
             within_days(int): timespan (in days) for latest event on case
             assignee(str): email of an assignee
+            verification_pending(bool): If search should be restricted to cases with verification_pending
 
         Returns:
             Cases ordered by date.
@@ -292,20 +290,16 @@ class CaseHandler(object):
                 instead returns corresponding query dict
                 that can be reused in compound queries or for testing.
         """
-        LOG.debug("Fetch all cases")
         query = query or {}
         order = None
-
         # Prioritize when both owner and collaborator params are present
         if collaborator and owner:
             collaborator = None
 
         if collaborator:
-            LOG.debug("Use collaborator {0}".format(collaborator))
             query["collaborators"] = collaborator
 
         if owner:
-            LOG.debug("Use owner {0}".format(owner))
             query["owner"] = owner
 
         if skip_assigned:
@@ -352,55 +346,109 @@ class CaseHandler(object):
             order = self._populate_name_query(query, name_query, owner, collaborator)
 
         if within_days:
-            verbs = set()
-
-            if has_causatives:
-                verbs.add("mark_causative")
-            if finished:
-                verbs.add("archive")
-                verbs.add("mark_causative")
-            if reruns:
-                verbs.add("rerun")
-            if research_requested:
-                verbs.add("open_research")
-            if status and status == "solved":
-                verbs.add("mark_causative")
-            verbs = list(verbs)
-
-            days_datetime = datetime.datetime.now() - datetime.timedelta(days=within_days)
-            # Look up 'mark_causative' events added since specified number days ago
-            event_query = {
-                "category": "case",
-                "verb": {"$in": verbs},
-                "created_at": {"$gte": days_datetime},
+            query["_id"] = {
+                "$in": self.last_modified_cases(
+                    within_days, has_causatives, finished, reruns, research_requested, status
+                )
             }
-            recent_events = self.event_collection.find(event_query)
-            recent_cases = set()
-            # Find what cases these events concern
-            for event in recent_events:
-                recent_cases.add(event["case"])
-            recent_cases = list(recent_cases)
-            query["_id"] = {"$in": recent_cases}
+
+        if verification_pending:  # Filter for cases with Sanger verification pending
+            sanger_pending_cases = self.verification_missing_cases(owner)
+            if query.get("_id"):  # Check if other filter already limits the search by case _id
+                preselected_ids = query["_id"].get("$in", [])
+                query["_id"]["$in"] = list(
+                    set(preselected_ids).intersection(set(sanger_pending_cases))
+                )  # limit also by Sanger pending
+            else:  # Apply only Sanger pending filter
+                query["_id"] = {"$in": sanger_pending_cases}
 
         if yield_query:
             return query
 
-        LOG.info(f"Get cases with query {query}")
         if order:
             return self.case_collection.find(query)
 
         return self.case_collection.find(query).sort("updated_at", -1)
 
+    def last_modified_cases(
+        self, within_days, has_causatives, finished, reruns, research_requested, status
+    ):
+        """Retrieve cases that have been modified during the last n. days
+        Args:
+            within_days(int)
+            has_causatives(bool)
+            finished(bool)
+            reruns(bool)
+            research_requested(bool)
+            status(str)
+
+        Returns:
+            recent_cases(list): list of case _ids
+        """
+        verbs = set()
+        if has_causatives:
+            verbs.add("mark_causative")
+        if finished:
+            verbs.add("archive")
+            verbs.add("mark_causative")
+        if reruns:
+            verbs.add("rerun")
+        if research_requested:
+            verbs.add("open_research")
+        if status and status == "solved":
+            verbs.add("mark_causative")
+        verbs = list(verbs)
+
+        days_datetime = datetime.datetime.now() - datetime.timedelta(days=within_days)
+        # Look up 'mark_causative' events added since specified number days ago
+        event_query = {
+            "category": "case",
+            "verb": {"$in": verbs},
+            "created_at": {"$gte": days_datetime},
+        }
+        recent_events = self.event_collection.find(event_query)
+        recent_cases = set()
+        # Find what cases these events concern
+        for event in recent_events:
+            recent_cases.add(event["case"])
+        return list(recent_cases)
+
+    def verification_missing_cases(self, institute_id):
+        """Fetch all cases with at least a variant with validation ordered but still pending
+        Args:
+            institute_id(str): id of an institute
+
+        Returns:
+            sanger_missing_cases(list): a list of case _ids with variants having Sanger validation missing
+        """
+        sanger_missing_cases = []
+        sanger_ordered_by_case = self.sanger_ordered(
+            institute_id=institute_id
+        )  # a list of dictionaries like this: [{'_id': 'internal_id', 'vars': ['a1d6df24404c007570021531b80b1e1e']}, ..]
+        for case_variants in sanger_ordered_by_case:
+            if self.case(case_id=case_variants["_id"]) is None:
+                continue
+            for variant_id in case_variants["vars"]:
+                var_obj = self.variant(case_id=case_variants["_id"], document_id=variant_id)
+
+                if var_obj is None or var_obj.get("validation") in [
+                    "True positive",
+                    "False positive",
+                ]:
+                    continue
+                sanger_missing_cases.append(case_variants["_id"])
+
+        return sanger_missing_cases
+
     def prioritized_cases(self, institute_id=None):
         """Fetches any prioritized cases from the backend.
 
         Args:
-            collaborator(str): If collaborator should be considered
+            institute_id(str): id of an institute
         """
         query = {}
 
         if institute_id:
-            LOG.debug("Use collaborator {0}".format(institute_id))
             query["collaborators"] = institute_id
 
         query["status"] = "prioritized"
@@ -440,7 +488,6 @@ class CaseHandler(object):
         if institute_id:
             query["collaborators"] = institute_id
 
-        LOG.debug("Fetch all cases with query {0}".format(query))
         nr_cases = sum(1 for i in self.case_collection.find(query))
 
         return nr_cases
@@ -452,6 +499,7 @@ class CaseHandler(object):
         hgnc_ids=None,
         phenotype_ids=None,
         add_only=False,
+        delete_only=False,
     ):
         """Update the dynamic gene list for a case
 
@@ -468,7 +516,8 @@ class CaseHandler(object):
             hgnc_symbols (iterable): A list of hgnc_symbols
             hgnc_ids (iterable): A list of hgnc_ids
             phenotype_ids(list): optionally add phenotype_ids used to generate list
-            add_only(bool): set by eg ADDGENE to add genes, and NOT reset previous dynamic_gene_list
+            add_only(bool): set by ADDGENE to add genes, and NOT reset previous dynamic_gene_list
+            delete_only(bool): set by REMOVEGENES when user removes genes from the auto-generated HPO panel
 
         Returns:
             updated_case(dict)
@@ -483,21 +532,16 @@ class CaseHandler(object):
                 ).get("dynamic_gene_list", [])
             )
 
-            LOG.debug("Add selected: current dynamic gene list: {}".format(dynamic_gene_list))
-
         res = []
         if hgnc_ids:
-            LOG.info("Fetching genes by hgnc id: {}".format(hgnc_ids))
             res = self.hgnc_collection.find({"hgnc_id": {"$in": hgnc_ids}, "build": build})
         elif hgnc_symbols:
-            LOG.info("Fetching genes by hgnc symbols")
             for symbol in hgnc_symbols:
                 those_genes = self.gene_aliases(symbol=symbol, build=build)
                 for gene_obj in those_genes:
                     res.append(gene_obj)
 
         for gene_obj in res:
-            LOG.debug("Appending gene {}".format(gene_obj["hgnc_symbol"]))
             dynamic_gene_list.append(
                 {
                     "hgnc_symbol": gene_obj["hgnc_symbol"],
@@ -505,20 +549,18 @@ class CaseHandler(object):
                     "description": gene_obj["description"],
                 }
             )
-
-        LOG.info("Update dynamic gene panel for: %s", case["display_name"])
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case["_id"]},
             {
                 "$set": {
                     "dynamic_gene_list": dynamic_gene_list,
-                    "dynamic_panel_phenotypes": phenotype_ids
-                    or case.get("dynamic_panel_phenotypes", []),
+                    "dynamic_panel_phenotypes": phenotype_ids,
+                    "dynamic_gene_list_edited": (add_only or delete_only)
+                    or (dynamic_gene_list and not phenotype_ids),
                 }
             },
             return_document=pymongo.ReturnDocument.AFTER,
         )
-        LOG.debug("Case updated")
         return updated_case
 
     def case(self, case_id=None, institute_id=None, display_name=None):
@@ -537,13 +579,11 @@ class CaseHandler(object):
         query = {}
         if case_id:
             query["_id"] = case_id
-            LOG.info("Fetching case %s", case_id)
         else:
             if not (institute_id and display_name):
                 raise ValueError(
                     "Please provide either case ID or both institute_id and display_name."
                 )
-            LOG.info("Fetching case %s institute %s", display_name, institute_id)
             query["owner"] = institute_id
             query["display_name"] = display_name
 
@@ -776,7 +816,10 @@ class CaseHandler(object):
         return self.case_collection.insert_one(case_obj)
 
     def update_case(self, case_obj, keep_date=False):
-        """Update a case in the database
+        """Update a case in the database.
+        While updating the case, it compares the date of the latest analysis (case_obj["analysis_date"]) against
+        the date of the analysis saved in db (old_case["analysis_date"]). If the 2 dates are different, it creates a new analysis
+        containing data from the old analysis under "analyses" in the updated case document.
 
         The following will be updated:
             - analysis_date: Is updated to the new date
@@ -833,44 +876,48 @@ class CaseHandler(object):
                 if ind.get("tissue_type") is None:
                     ind["tissue_type"] = old_ind.get("tissue_type")
 
+        analysis_date = case_obj["analysis_date"]
+        old_analysis_date = old_case["analysis_date"]
+        update_actions = {
+            "$addToSet": {"collaborators": {"$each": case_obj["collaborators"]}},
+            "$set": {
+                "analysis_date": analysis_date,
+                "custom_images": case_obj.get("custom_images"),
+                "cnv_report": case_obj.get("cnv_report"),
+                "coverage_qc_report": case_obj.get("coverage_qc_report"),
+                "delivery_report": case_obj.get("delivery_report"),
+                "gene_fusion_report": case_obj.get("gene_fusion_report"),
+                "gene_fusion_report_research": case_obj.get("gene_fusion_report_research"),
+                "genome_build": case_obj.get("genome_build", "37"),
+                "has_strvariants": case_obj.get("has_strvariants"),
+                "has_svvariants": case_obj.get("has_svvariants"),
+                "individuals": case_obj["individuals"],
+                "is_research": case_obj.get("is_research", False),
+                "madeline_info": case_obj.get("madeline_info"),
+                "mme_submission": case_obj.get("mme_submission"),
+                "multiqc": case_obj.get("multiqc"),
+                "panels": case_obj.get("panels", []),
+                "rank_model_version": case_obj.get("rank_model_version"),
+                "rerun_requested": case_obj.get("rerun_requested", False),
+                "research_requested": case_obj.get("research_requested", False),
+                "smn_tsv": case_obj.get("smn_tsv"),
+                "status": case_obj.get("status"),
+                "sv_rank_model_version": case_obj.get("sv_rank_model_version"),
+                "track": case_obj.get("track", "rare"),
+                "updated_at": updated_at,
+                "vcf_files": case_obj.get("vcf_files"),
+            },
+        }
+        analysis_dates = [analysis.get("date") for analysis in old_case.get("analyses", [])]
+        if analysis_date != old_analysis_date and old_analysis_date not in analysis_dates:
+            update_actions["$addToSet"]["analyses"] = {
+                "date": old_analysis_date,
+                "delivery_report": old_case.get("delivery_report"),
+            }
+
         updated_case = self.case_collection.find_one_and_update(
             {"_id": case_obj["_id"]},
-            {
-                "$addToSet": {
-                    "collaborators": {"$each": case_obj["collaborators"]},
-                    "analyses": {
-                        "date": old_case["analysis_date"],
-                        "delivery_report": old_case.get("delivery_report"),
-                    },
-                },
-                "$set": {
-                    "analysis_date": case_obj["analysis_date"],
-                    "custom_images": case_obj.get("custom_images"),
-                    "cnv_report": case_obj.get("cnv_report"),
-                    "coverage_qc_report": case_obj.get("coverage_qc_report"),
-                    "delivery_report": case_obj.get("delivery_report"),
-                    "gene_fusion_report": case_obj.get("gene_fusion_report"),
-                    "gene_fusion_report_research": case_obj.get("gene_fusion_report_research"),
-                    "genome_build": case_obj.get("genome_build", "37"),
-                    "has_strvariants": case_obj.get("has_strvariants"),
-                    "has_svvariants": case_obj.get("has_svvariants"),
-                    "individuals": case_obj["individuals"],
-                    "is_research": case_obj.get("is_research", False),
-                    "madeline_info": case_obj.get("madeline_info"),
-                    "mme_submission": case_obj.get("mme_submission"),
-                    "multiqc": case_obj.get("multiqc"),
-                    "panels": case_obj.get("panels", []),
-                    "rank_model_version": case_obj.get("rank_model_version"),
-                    "rerun_requested": case_obj.get("rerun_requested", False),
-                    "research_requested": case_obj.get("research_requested", False),
-                    "smn_tsv": case_obj.get("smn_tsv"),
-                    "status": case_obj.get("status"),
-                    "sv_rank_model_version": case_obj.get("sv_rank_model_version"),
-                    "track": case_obj.get("track", "rare"),
-                    "updated_at": updated_at,
-                    "vcf_files": case_obj.get("vcf_files"),
-                },
-            },
+            update_actions,
             return_document=pymongo.ReturnDocument.AFTER,
         )
 
@@ -994,7 +1041,6 @@ class CaseHandler(object):
         case_verif_variants = {"sanger_verified": [], "sanger_ordered": []}
 
         # Add the verified variants
-        LOG.info("Fetching all sanger variants and all validated variants")
         results = {
             "sanger_verified": self.validated(case_id=case_id),
             "sanger_ordered": self.sanger_ordered(case_id=case_id),
