@@ -7,10 +7,11 @@ functions to load panels into the database
 import logging
 
 from click import Abort
+from flask.cli import current_app
 
 from scout.parse.panel import get_panel_info, parse_gene_panel, parse_panel_app_panel
 from scout.utils.handle import get_file_handle
-from scout.utils.scout_requests import fetch_resource
+from scout.utils.scout_requests import fetch_mim_files, fetch_resource
 
 LOG = logging.getLogger(__name__)
 
@@ -105,7 +106,7 @@ def load_panel(panel_path, adapter, **kwargs):
         raise err
 
 
-def load_panel_app(adapter, panel_id=None, institute="cust000"):
+def load_panelapp_panel(adapter, panel_id=None, institute="cust000", confidence="green"):
     """Load PanelApp panels into scout database
 
     If no panel_id load all PanelApp panels
@@ -113,6 +114,7 @@ def load_panel_app(adapter, panel_id=None, institute="cust000"):
     Args:
         adapter(scout.adapter.MongoAdapter)
         panel_id(str): The panel app panel id
+        confidence(str enum green|amber|red): traffic light-style PanelApp level of confidence
     """
     base_url = "https://panelapp.genomicsengland.co.uk/WebServices/{0}/"
 
@@ -121,7 +123,6 @@ def load_panel_app(adapter, panel_id=None, institute="cust000"):
     panel_ids = [panel_id]
 
     if not panel_id:
-
         LOG.info("Fetching all panel app panels")
         json_lines = fetch_resource(base_url.format("list_panels"), json=True)
 
@@ -129,11 +130,16 @@ def load_panel_app(adapter, panel_id=None, institute="cust000"):
 
     for _panel_id in panel_ids:
         json_lines = fetch_resource(base_url.format("get_panel") + _panel_id, json=True)
-
         parsed_panel = parse_panel_app_panel(
-            panel_info=json_lines["result"], hgnc_map=hgnc_map, institute=institute
+            panel_info=json_lines["result"],
+            hgnc_map=hgnc_map,
+            institute=institute,
+            confidence=confidence,
         )
-        parsed_panel["panel_id"] = _panel_id
+        if confidence != "green":
+            parsed_panel["panel_id"] = "_".join([_panel_id, confidence])
+        else:  # This way the old green panels will be overwritten, instead of creating 2 sets of green panels, old and new
+            parsed_panel["panel_id"] = _panel_id
 
         if len(parsed_panel["genes"]) == 0:
             LOG.warning("Panel %s is missing genes. Skipping.", parsed_panel["display_name"])
@@ -143,3 +149,47 @@ def load_panel_app(adapter, panel_id=None, institute="cust000"):
             adapter.load_panel(parsed_panel=parsed_panel, replace=True)
         except Exception as err:
             raise err
+
+
+def load_omim_panel(adapter, genemap2, mim2genes, api_key, institute):
+    """Add OMIM panel to the database.
+    Args:
+        adapter(scout.adapter.MongoAdapter)
+        genemap2(str): Path to file in omim genemap2 format
+        mim2genes(str): Path to file in omim mim2genes format
+        api_key(str): OMIM API key
+        institute(str): institute _id
+    """
+
+    mim_files = None
+    if genemap2 and mim2genes:
+        mim_files = {
+            "genemap2": list(get_file_handle(genemap2)),
+            "mim2genes": list(get_file_handle(mim2genes)),
+        }
+
+    api_key = api_key or current_app.config.get("OMIM_API_KEY")
+    if not api_key and mim_files is None:
+        LOG.warning(
+            "Please provide either an OMIM api key or the path to genemap2 and mim2genesto to load the omim gene panel"
+        )
+        return
+    # Check if OMIM-AUTO exists
+    if adapter.gene_panel(panel_id="OMIM-AUTO"):
+        LOG.warning(
+            "OMIM-AUTO already exists in database. Use the command 'scout update omim' to create a new OMIM panel version"
+        )
+        return
+
+    if not mim_files:
+        mim_files = fetch_mim_files(api_key=api_key, genemap2=True, mim2genes=True)
+
+    # Here we know that there is no panel loaded
+    try:
+        adapter.load_omim_panel(
+            genemap2_lines=mim_files["genemap2"],
+            mim2gene_lines=mim_files["mim2genes"],
+            institute=institute,
+        )
+    except Exception as err:
+        LOG.error(err)
