@@ -93,16 +93,9 @@ def get_submission_variants(form_fields):
     """
 
     clinvars = []
-
-    # if the html checkbox named 'all_vars' is checked in the html form, then all pinned variants from a case should be included in the clinvar submission file,
-    # otherwise just the selected one.
-    if "all_vars" in form_fields:
-        for field, value in form_fields.items():
-            if field.startswith("local_id"):
-                clinvars.append(form_fields[field].replace("local_id@", ""))
-    else:
-        clinvars = [form_fields["main_var"]]  # also a list, but has one element
-
+    for field, value in form_fields.items():
+        if field.startswith("local_id"):
+            clinvars.append(form_fields[field].replace("local_id@", ""))
     return clinvars
 
 
