@@ -11,7 +11,6 @@ import requests
 from bson.objectid import ObjectId
 from flask import current_app, flash, redirect, request, url_for
 from flask_login import current_user
-from flask_mail import Message
 from requests.auth import HTTPBasicAuth
 from xlsxwriter import Workbook
 
@@ -21,6 +20,7 @@ from scout.constants import (
     CASE_REPORT_CASE_FEATURES,
     CASE_REPORT_CASE_IND_FEATURES,
     CASE_REPORT_VARIANT_TYPES,
+    MITODEL_HEADER,
     MT_COV_STATS_HEADER,
     MT_EXPORT_HEADER,
     PHENOTYPE_GROUPS,
@@ -43,7 +43,6 @@ from scout.server.blueprints.variant.controllers import variant as variant_decor
 from scout.server.blueprints.variants.controllers import get_manual_assessments
 from scout.server.extensions import RerunnerError, gens, matchmaker, rerunner, store
 from scout.server.utils import case_has_alignments, case_has_mt_alignments, institute_and_case
-from scout.utils.scout_requests import delete_request_json, post_request_json
 
 LOG = logging.getLogger(__name__)
 
@@ -56,6 +55,28 @@ JSON_HEADERS = {
 COVERAGE_REPORT_TIMEOUT = 20
 
 
+def phenomizer_diseases(hpo_ids, case_obj, p_value_treshold=1):
+    """Return the list of HGNC symbols that match annotated HPO terms on Phenomizer
+    Args:
+        hpo_ids(list)
+        case_obj(models.Case)
+
+    Returns:
+        diseases(list of dictionaries) or None. Results contains the following key/values: p_value, gene_symbols, disease_nr, disease_source, OMIM, description, raw_line
+    """
+    if len(hpo_ids) == 0:
+        hpo_ids = [term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])]
+
+    username = current_app.config["PHENOMIZER_USERNAME"]
+    password = current_app.config["PHENOMIZER_PASSWORD"]
+    try:
+        results = query_phenomizer.query(username, password, *hpo_ids)
+        diseases = [result for result in results if result["p_value"] <= p_value_treshold]
+        return diseases
+    except RuntimeError:
+        flash("Could not establish a conection to Phenomizer", "danger")
+
+
 def coverage_report_contents(base_url, institute_obj, case_obj):
     """Capture the contents of a case coverage report (chanjo-report), to be displayed in the general case report
 
@@ -194,7 +215,10 @@ def case(store, institute_obj, case_obj):
     distinct_genes = set()
     case_obj["panel_names"] = []
     case_obj["outdated_panels"] = {}
+
     for panel_info in case_obj.get("panels", []):
+        if not panel_info.get("display_name"):
+            panel_info["display_name"] = panel_info["panel_name"]
         if not panel_info.get("is_default"):
             continue
         panel_name = panel_info["panel_name"]
@@ -225,6 +249,7 @@ def case(store, institute_obj, case_obj):
         full_name = "{} ({})".format(panel_obj["display_name"], panel_obj["version"])
         case_obj["panel_names"].append(full_name)
 
+    case_obj["panels"] = sorted(case_obj.get("panels", []), key=lambda d: d["display_name"])
     case_obj["default_genes"] = list(distinct_genes)
 
     for hpo_term in itertools.chain(
@@ -304,12 +329,19 @@ def case(store, institute_obj, case_obj):
             for img in case_obj["custom_images"][img_section]:
                 img["data"] = b64encode(img["data"]).decode("utf-8")
 
+    # Limit secondary findings according to institute settings
+    limit_genes = store.safe_genes_filter(institute_obj["_id"])
+
     data = {
         "institute": institute_obj,
         "case": case_obj,
         "status_class": STATUS_MAP.get(case_obj["status"]),
-        "other_causatives": [var for var in store.check_causatives(case_obj=case_obj)],
-        "managed_variants": [var for var in store.check_managed(case_obj=case_obj)],
+        "other_causatives": [
+            var for var in store.check_causatives(case_obj=case_obj, limit_genes=limit_genes)
+        ],
+        "managed_variants": [
+            var for var in store.check_managed(case_obj=case_obj, limit_genes=limit_genes)
+        ],
         "comments": store.events(institute_obj, case=case_obj, comments=True),
         "hpo_groups": pheno_groups,
         "case_groups": case_groups,
@@ -627,6 +659,15 @@ def mt_excel_files(store, case_obj, temp_excel_dir):
             for col, item in enumerate(["mt_coverage", "autosome_cov", "mt_copy_number"]):
                 Report_Sheet.write(row + 4, col, coverage_stats[sample_id].get(item))
 
+        mitodel = sample.get("mitodel")
+
+        if mitodel:
+            for col, field in enumerate(MITODEL_HEADER):
+                Report_Sheet.write(row + 6, col, field)
+
+            for col, item in enumerate(["normal", "discordant", "ratioppk"]):
+                Report_Sheet.write(row + 7, col, mitodel.get(item))
+
         workbook.close()
 
         if os.path.exists(os.path.join(temp_excel_dir, document_name)):
@@ -745,7 +786,7 @@ def phenotypes_genes(store, case_obj, is_clinical=True):
 
     all_hpo_gene_list_genes = set()
     # Loop over the dynamic phenotypes of a case
-    for hpo_id in hpo_gene_list:
+    for hpo_id in hpo_gene_list or []:
         hpo_term = store.hpo_term(hpo_id)
         # Check that HPO term exists in database
         if hpo_term is None:
@@ -814,72 +855,6 @@ def hpo_genes_from_dynamic_gene_list(case_obj, is_clinical, clinical_symbols):
     return unique_genes
 
 
-def hpo_diseases(username, password, hpo_ids, p_value_treshold=1):
-    """Return the list of HGNC symbols that match annotated HPO terms.
-
-    Args:
-        username (str): username to use for phenomizer connection
-        password (str): password to use for phenomizer connection
-
-    Returns:
-        query_result: a generator of dictionaries on the form
-        {
-            'p_value': float,
-            'disease_source': str,
-            'disease_nr': int,
-            'gene_symbols': list(str),
-            'description': str,
-            'raw_line': str
-        }
-    """
-    # skip querying Phenomizer unless at least one HPO terms exists
-    try:
-        results = query_phenomizer.query(username, password, *hpo_ids)
-        diseases = [result for result in results if result["p_value"] <= p_value_treshold]
-        return diseases
-    except RuntimeError:
-        flash("Could not establish a conection to Phenomizer", "danger")
-
-
-def rerun(store, mail, current_user, institute_id, case_name, sender, recipient):
-    """Request a rerun by email."""
-
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    user_obj = store.user(current_user.email)
-    link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
-
-    if case_obj.get("rerun_requested") and case_obj["rerun_requested"] is True:
-        flash("Rerun already pending", "info")
-        return
-
-    store.request_rerun(institute_obj, case_obj, user_obj, link)
-
-    # this should send a JSON document to the SuSy API in the future
-    html = """
-        <p>{institute}: {case} ({case_id})</p>
-        <p>Re-run requested by: {name}</p>
-    """.format(
-        institute=institute_obj["display_name"],
-        case=case_obj["display_name"],
-        case_id=case_obj["_id"],
-        name=user_obj["name"].encode(),
-    )
-
-    # compose and send the email message
-    msg = Message(
-        subject=("SCOUT: request RERUN for {}".format(case_obj["display_name"])),
-        html=html,
-        sender=sender,
-        recipients=[recipient],
-        # cc the sender of the email for confirmation
-        cc=[user_obj["email"]],
-    )
-    if recipient:
-        mail.send(msg)
-    else:
-        LOG.error("Cannot send rerun message: no recipient defined in config.")
-
-
 def call_rerunner(store, institute_id, case_name, metadata):
     """Call rerunner with updated pedigree metadata."""
     # define the data to be passed
