@@ -23,7 +23,7 @@ from flask import (
 from flask_login import current_user
 
 from scout.constants import CUSTOM_CASE_REPORTS
-from scout.server.extensions import beacon, mail, store
+from scout.server.extensions import beacon, store
 from scout.server.utils import (
     html_to_pdf_file,
     institute_and_case,
@@ -32,6 +32,7 @@ from scout.server.utils import (
     user_institutes,
     zip_dir_to_obj,
 )
+from scout.utils.gene import parse_raw_gene_ids, parse_raw_gene_symbols
 
 from . import controllers
 
@@ -280,7 +281,7 @@ def mt_report(institute_id, case_name):
             mimetype="application/zip",
             as_attachment=True,
             download_name="_".join(["scout", case_name, "MT_report", today]) + ".zip",
-            cache_timeout=0,
+            max_age=0,
         )
 
     shutil.rmtree(temp_excel_dir)
@@ -361,59 +362,6 @@ def phenotypes(institute_id, case_name, phenotype_id=None):
     return redirect("#".join([case_url, "phenotypes_panel"]))
 
 
-def parse_raw_gene_ids(raw_symbols):
-    """Parse raw gene symbols for hgnc_symbols from web form autocompletion.
-
-    Arguments:
-        raw_symbol_strings(list(string)) - formated "17284 | POT1 (hPot1, POT1)"
-
-    Returns:
-        hgnc_ids(set(int))
-    """
-    hgnc_ids = set()
-
-    for raw_symbol in raw_symbols:
-        LOG.debug("raw gene: {}".format(raw_symbol))
-        # avoid empty lists
-        if raw_symbol:
-            # take the first nubmer before |, and remove any space.
-            try:
-                hgnc_ids.add(int(raw_symbol.split("|", 1)[0].replace(" ", "")))
-            except ValueError:
-                flash(
-                    "Provided gene info could not be parsed! "
-                    "Please allow autocompletion to finish.",
-                    "warning",
-                )
-
-    LOG.debug("Parsed HGNC symbols {}".format(hgnc_ids))
-
-    return hgnc_ids
-
-
-def parse_raw_gene_symbols(raw_symbols_list):
-    """Parse list of concatenated gene symbol list for hgnc_symbols from Phenomizer.
-
-    Arguments:
-        raw_symbols(list(string)) - e.g. ("POT1 | MUTYH", "POT1 | ATXN1 | ATXN7")
-
-    Returns:
-        hgnc_symbols(set(string)) - set of (unique) gene symbols without intervening chars
-    """
-    hgnc_symbols = set()
-
-    for raw_symbols in raw_symbols_list:
-        LOG.debug("raw gene: {}".format(raw_symbols))
-        # avoid empty lists
-        if raw_symbols:
-            hgnc_symbols.update(
-                raw_symbol.split(" ", 1)[0] for raw_symbol in raw_symbols.split("|")
-            )
-    LOG.debug("Parsed HGNC symbols {}".format(hgnc_symbols))
-
-    return hgnc_symbols
-
-
 @cases_bp.route("/<institute_id>/<case_name>/phenotypes/actions", methods=["POST"])
 def phenotypes_actions(institute_id, case_name):
     """Perform actions on multiple phenotypes."""
@@ -424,12 +372,7 @@ def phenotypes_actions(institute_id, case_name):
     user_obj = store.user(current_user.email)
 
     if action == "PHENOMIZER":
-        if len(hpo_ids) == 0:
-            hpo_ids = [term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])]
-
-        username = current_app.config["PHENOMIZER_USERNAME"]
-        password = current_app.config["PHENOMIZER_PASSWORD"]
-        diseases = controllers.hpo_diseases(username, password, hpo_ids)
+        diseases = controllers.phenomizer_diseases(hpo_ids, case_obj)
         if diseases:
             return render_template(
                 "cases/diseases.html",
@@ -444,16 +387,29 @@ def phenotypes_actions(institute_id, case_name):
             store.remove_phenotype(institute_obj, case_obj, user_obj, case_url, hpo_id)
 
     if action == "ADDGENE":
-        hgnc_ids = parse_raw_gene_ids(request.form.getlist("genes"))
+        try:
+            hgnc_ids = parse_raw_gene_ids(request.form.getlist("genes"))
+        except ValueError:
+            flash(
+                "Provided gene info could not be parsed!. Please allow autocompletion to finish.",
+                "warning",
+            )
         store.update_dynamic_gene_list(case_obj, hgnc_ids=list(hgnc_ids), add_only=True)
 
+    if action == "REMOVEGENES":  # Remove one or more genes from the dynamic gene list
+        case_dynamic_genes = [dyn_gene["hgnc_id"] for dyn_gene in case_obj.get("dynamic_gene_list")]
+        genes_to_remove = [int(gene_id) for gene_id in request.form.getlist("dynamicGene")]
+        store.update_dynamic_gene_list(
+            case_obj,
+            hgnc_ids=list(set(case_dynamic_genes) - set(genes_to_remove)),
+            delete_only=True,
+        )
+
     if action == "GENES":
         hgnc_symbols = parse_raw_gene_symbols(request.form.getlist("genes"))
         store.update_dynamic_gene_list(case_obj, hgnc_symbols=list(hgnc_symbols))
 
     if action == "GENERATE":
-        if len(hpo_ids) == 0:
-            hpo_ids = [term["phenotype_id"] for term in case_obj.get("phenotype_terms", [])]
         results = store.generate_hpo_gene_list(*hpo_ids)
         # determine how many HPO terms each gene must match
         hpo_count = int(request.form.get("min_match") or 1)
@@ -814,14 +770,15 @@ def share(institute_id, case_name):
     return redirect(request.referrer)
 
 
-@cases_bp.route("/<institute_id>/<case_name>/rerun", methods=["POST"])
-def rerun(institute_id, case_name):
-    """Request a case to be rerun."""
-    sender = current_app.config.get("MAIL_USERNAME")
-    recipient = current_app.config.get("TICKET_SYSTEM_EMAIL")
+@cases_bp.route("/<institute_id>/<case_name>/update_rerun_status")
+def update_rerun_status(institute_id, case_name):
+    """Update rerun status for a case by setting rerun_requested to True or False"""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    user_obj = store.user(current_user.email)
+    link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
 
-    controllers.rerun(store, mail, current_user, institute_id, case_name, sender, recipient)
-    return redirect(request.referrer)
+    store.update_rerun_status(institute_obj, case_obj, user_obj, link)
+    return redirect(link)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/monitor", methods=["POST"])
@@ -830,7 +787,6 @@ def rerun_monitor(institute_id, case_name):
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     user_obj = store.user(current_user.email)
     link = url_for(".case", institute_id=institute_id, case_name=case_name)
-
     if request.form.get("rerun_monitoring") == "monitor":
         store.monitor(institute_obj, case_obj, user_obj, link)
     else:
