@@ -9,13 +9,7 @@ from flask import current_app, flash, url_for
 from flask_login import current_user
 from pymongo import ASCENDING, DESCENDING
 
-from scout.constants import (
-    ACMG_COMPLETE_MAP,
-    ACMG_MAP,
-    CASE_SEARCH_TERMS,
-    CASE_STATUSES,
-    PHENOTYPE_GROUPS,
-)
+from scout.constants import CASE_SEARCH_TERMS, CASE_STATUSES, PHENOTYPE_GROUPS
 from scout.parse.clinvar import clinvar_submission_header, clinvar_submission_lines
 from scout.server.blueprints.variant.utils import predictions, update_representative_gene
 from scout.server.extensions import beacon, store
@@ -75,6 +69,51 @@ def get_timeline_data(limit):
     return timeline_results
 
 
+def verified_vars(institute_id):
+    """Create content to be displayed on institute verified page
+
+    Args:
+        institute_id(str): institute["_id"] value
+
+    Returns:
+        verified(list): list of variant objects (True positive or False Positive)
+    """
+    verified = []
+    for variant_obj in store.verified(institute_id=institute_id):
+        variant_genes = variant_obj.get("genes", [])
+        if variant_obj["category"] in ["snv", "cancer"]:
+            update_representative_gene(
+                variant_obj, variant_genes
+            )  # required to display cDNA and protein change
+        variant_obj.update(predictions(variant_genes))
+        verified.append(variant_obj)
+
+    return verified
+
+
+def verified_stats(institute_id, verified_vars):
+    """Create content to be displayed on institute verified page, stats chart
+
+    Args:
+        institute_id(str): institute["_id"] value
+        verified_vars(list): a list of verified varianst (True positive or False Positive)
+
+    Returns:
+        stats(tuple) -> True positives, False positives, validation unknown
+
+    """
+    true_pos = 0
+    false_pos = 0
+    for var in verified_vars:
+        if var.get("validation") == "True positive":
+            true_pos += 1
+        else:
+            false_pos += 1
+
+    n_validations_ordered = len(list(store.validations_ordered(institute_id)))
+    return true_pos, false_pos, n_validations_ordered - (true_pos + false_pos)
+
+
 def causatives(institute_obj, request):
     """Create content to be displayed on institute causatives page
 
@@ -83,7 +122,7 @@ def causatives(institute_obj, request):
         request(flask.request) request sent by user's browser
 
     Returns:
-        data(dict)
+        causatives(list of dictionaries)
     """
     # Retrieve variants grouped by case
     query = request.args.get("query", "")
@@ -95,37 +134,28 @@ def causatives(institute_obj, request):
         except ValueError:
             flash("Provided gene info could not be parsed!", "warning")
 
-    variants = list(store.check_causatives(institute_obj=institute_obj, limit_genes=hgnc_id))
-    if variants:
-        variants = sorted(
-            variants,
-            key=lambda k: k.get("hgnc_symbols", [None])[0] or k.get("str_repid") or "",
-        )
+    causatives = []
 
-    all_variants = {}
-    all_cases = {}
-    for variant_obj in variants:
+    for variant_obj in store.check_causatives(institute_obj=institute_obj, limit_genes=hgnc_id):
+        variant_genes = variant_obj.get("genes", [])
         if variant_obj["category"] in ["snv", "cancer"]:
             update_representative_gene(
-                variant_obj, variant_obj.get("genes", [])
+                variant_obj, variant_genes
             )  # required to display cDNA and protein change
-        if variant_obj["case_id"] not in all_cases:
-            case_obj = store.case(variant_obj["case_id"])
-            all_cases[variant_obj["case_id"]] = case_obj
-        else:
-            case_obj = all_cases[variant_obj["case_id"]]
+        variant_obj.update(predictions(variant_genes))
+        case_obj = store.case(variant_obj["case_id"])
+        if not case_obj:
+            continue
+        variant_obj["case_obj"] = {
+            "display_name": case_obj["display_name"],
+            "individuals": case_obj["individuals"],
+            "status": case_obj.get("status"),
+            "partial_causatives": case_obj.get("partial_causatives", []),
+        }
 
-        if variant_obj["variant_id"] not in all_variants:
-            all_variants[variant_obj["variant_id"]] = []
+        causatives.append(variant_obj)
 
-        all_variants[variant_obj["variant_id"]].append((case_obj, variant_obj))
-
-    data = dict(
-        institute=institute_obj,
-        variant_groups=all_variants,
-        acmg_map={key: ACMG_COMPLETE_MAP[value] for key, value in ACMG_MAP.items()},
-    )
-    return data
+    return causatives
 
 
 def institutes():
@@ -244,6 +274,7 @@ def populate_institute_form(form, institute_obj):
     for panel in available_panels:
         panel_set.add((panel["panel_name"], panel["display_name"]))
     form.gene_panels.choices = sorted(panel_set, key=lambda tup: tup[1])
+    form.gene_panels_matching.choices = sorted(panel_set, key=lambda tup: tup[1])
 
     return default_phenotypes
 
@@ -264,6 +295,7 @@ def update_institute_settings(store, institute_obj, form):
     sharing_institutes = []
     phenotype_groups = []
     gene_panels = {}
+    gene_panels_matching = {}
     group_abbreviations = []
     cohorts = []
 
@@ -287,6 +319,12 @@ def update_institute_settings(store, institute_obj, form):
             continue
         gene_panels[panel_name] = panel_obj["display_name"]
 
+    for panel_name in form.getlist("gene_panels_matching"):
+        panel_obj = store.gene_panel(panel_name)
+        if panel_obj is None:
+            continue
+        gene_panels_matching[panel_name] = panel_obj["display_name"]
+
     for cohort in form.getlist("cohorts"):
         cohorts.append(cohort.strip())
 
@@ -298,12 +336,14 @@ def update_institute_settings(store, institute_obj, form):
         display_name=form.get("display_name"),
         phenotype_groups=phenotype_groups,
         gene_panels=gene_panels,
+        gene_panels_matching=gene_panels_matching,
         group_abbreviations=group_abbreviations,
         add_groups=False,
         sharing_institutes=sharing_institutes,
         cohorts=cohorts,
         loqusdb_ids=form.getlist("loqusdb_id"),
         alamut_key=form.get("alamut_key"),
+        check_show_all_vars=form.get("check_show_all_vars"),
     )
     return updated_institute
 
@@ -362,25 +402,20 @@ def cases(store, request, institute_id):
         )
     data["name_query"] = name_query
     limit = int(request.args.get("search_limit")) if request.args.get("search_limit") else 100
-    skip_assigned = request.args.get("skip_assigned")
     data["form"] = populate_case_filter_form(request.args)
-    data["skip_assigned"] = skip_assigned
-    is_research = request.args.get("is_research")
-    data["is_research"] = is_research
+
     prioritized_cases = store.prioritized_cases(institute_id=institute_id)
     all_cases = store.cases(
         collaborator=institute_id,
         name_query=name_query,
-        skip_assigned=skip_assigned,
-        is_research=is_research,
+        skip_assigned=request.args.get("skip_assigned"),
+        is_research=request.args.get("is_research"),
+        verification_pending=request.args.get("validation_ordered"),
     )
     all_cases = _sort_cases(data, request, all_cases)
 
     data["nr_cases"] = store.nr_cases(institute_id=institute_id)
-
-    sanger_unevaluated = get_sanger_unevaluated(store, institute_id, current_user.email)
-    if len(sanger_unevaluated) > 0:
-        data["sanger_unevaluated"] = sanger_unevaluated
+    data["sanger_unevaluated"] = get_sanger_unevaluated(store, institute_id, current_user.email)
 
     case_groups = {status: [] for status in CASE_STATUSES}
     nr_cases = 0
@@ -398,13 +433,15 @@ def cases(store, request, institute_id):
             store.user(user_email) for user_email in case_obj.get("assignees", [])
         ]
         # Check if case was re-runned
-        analyses = case_obj.get("analyses", [])
-        now = datetime.datetime.now()
-        case_obj["is_rerun"] = (
-            len(analyses) > 1
-            or analyses
-            and analyses[0].get("date", now) < case_obj.get("analysis_date", now)
+        last_analysis_date = case_obj.get("analysis_date", datetime.datetime.now())
+        all_analyses_dates = set()
+        for analysis in case_obj.get("analyses", [{"date": last_analysis_date}]):
+            all_analyses_dates.add(analysis.get("date", last_analysis_date))
+
+        case_obj["is_rerun"] = len(all_analyses_dates) > 1 or last_analysis_date > max(
+            all_analyses_dates
         )
+
         case_obj["clinvar_variants"] = store.case_to_clinVars(case_obj["_id"])
         case_obj["display_track"] = TRACKS[case_obj.get("track", "rare")]
         return case_obj
@@ -516,50 +553,16 @@ def gene_variants(store, pymongo_cursor, variant_count, page=1, per_page=50):
     skip_count = per_page * max(page - 1, 0)
     more_variants = True if variant_count > (skip_count + per_page) else False
     variant_res = pymongo_cursor.skip(skip_count).limit(per_page)
-    my_institutes = set(inst["_id"] for inst in user_institutes(store, current_user))
     variants = []
 
     for variant_obj in variant_res:
         # Populate variant case_display_name
         variant_case_obj = store.case(case_id=variant_obj["case_id"])
-        if not variant_case_obj:
-            # A variant with missing case was encountered
-            continue
         case_display_name = variant_case_obj.get("display_name")
         variant_obj["case_display_name"] = case_display_name
 
-        # hide other institutes for now
-        other_institutes = set([variant_case_obj.get("owner")])
-        other_institutes.update(set(variant_case_obj.get("collaborators", [])))
-        if my_institutes.isdisjoint(other_institutes):
-            # If the user does not have access to the information we skip it
-            continue
-
         genome_build = get_genome_build(variant_case_obj)
-        variant_genes = variant_obj.get("genes")
-        update_HGNC_symbols(store, variant_genes, genome_build)
-
-        # Populate variant HGVS and predictions
-        variant_genes = variant_obj.get("genes")
-        hgvs_c = []
-        hgvs_p = []
-        if variant_genes is not None:
-            for gene_obj in variant_genes:
-                hgnc_id = gene_obj["hgnc_id"]
-                gene_caption = store.hgnc_gene_caption(hgnc_id)
-                gene_symbols = [gene_caption["hgnc_symbol"]]
-
-                # gather HGVS info from gene transcripts
-                (hgvs_nucleotide, hgvs_protein) = get_hgvs(gene_obj)
-                hgvs_c.append(hgvs_nucleotide)
-                hgvs_p.append(hgvs_protein)
-
-            if len(gene_symbols) == 1:
-                variant_obj["hgvs"] = hgvs_str(gene_symbols, hgvs_p, hgvs_c)
-
-            # populate variant predictions for display
-            variant_obj.update(predictions(variant_genes))
-
+        update_variant_genes(store, variant_obj, genome_build)
         variants.append(variant_obj)
 
     return {"variants": variants, "more_variants": more_variants}
@@ -704,28 +707,44 @@ def clinvar_lines(clinvar_objects, clinvar_header_obj):
     return clinvar_lines
 
 
-def update_HGNC_symbols(store, variant_genes, genome_build):
-    """Update the HGNC symbols if they are not set
-    Returns:
-        gene_object()"""
+def update_variant_genes(store, variant_obj, genome_build):
+    """Update the HGNC symbols and HGVS predictions if they are not set
 
-    if variant_genes is not None:
-        for gene_obj in variant_genes:
-            # If there is no hgnc id there is nothin we can do
-            if not gene_obj["hgnc_id"]:
-                continue
-            # Else we collect the gene object and check the id
-            if gene_obj.get("hgnc_symbol") is None or gene_obj.get("description") is None:
-                hgnc_gene_caption = store.hgnc_gene_caption(gene_obj["hgnc_id"], build=genome_build)
-                if not hgnc_gene_caption:
-                    continue
-                gene_obj["hgnc_symbol"] = hgnc_gene_caption["hgnc_symbol"]
-                gene_obj["description"] = hgnc_gene_caption["description"]
+    Accepts:
+        store(adapter.MongoAdapter)
+        variant_obj(scout.models.variant.Variant): a dictionary
+        genome_build(str): "37" or "38"
+    """
+
+    hgvs_c = []
+    hgvs_p = []
+    gene_symbols = set()
+
+    for gene_obj in variant_obj.get("genes", []):
+        hgnc_id = gene_obj.get("hgnc_id")
+        if hgnc_id is None:
+            continue
+        gene_caption = store.hgnc_gene_caption(hgnc_id, genome_build)
+        if gene_caption is None:
+            continue
+        # Make sure that gene symbol and description have a value
+        gene_obj["hgnc_symbol"] = gene_caption["hgnc_symbol"]
+        gene_obj["description"] = gene_caption["description"]
+
+        gene_symbols.add(gene_obj["hgnc_symbol"])
+
+        # gather HGVS info from gene transcripts
+        (hgvs_nucleotide, hgvs_protein) = get_hgvs(gene_obj)
+        hgvs_c.append(hgvs_nucleotide)
+        hgvs_p.append(hgvs_protein)
+
+    if len(gene_symbols) == 1:
+        variant_obj["hgvs"] = hgvs_str(list(gene_symbols), hgvs_p, hgvs_c)
 
 
 def get_genome_build(variant_case_obj):
     """Find genom build in `variant_case_obj`. If not found use build #37"""
-    build = variant_case_obj.get("genome_build")
+    build = str(variant_case_obj.get("genome_build"))
     if build in ["37", "38"]:
         return build
     return "37"
