@@ -72,19 +72,27 @@ class InstituteForm(FlaskForm):
     pheno_abbrev = StringField("Abbreviation", validators=[validators.Optional()])
 
     gene_panels = NonValidatingSelectMultipleField(
-        "Gene panels for variants filtering", validators=[validators.Optional()]
+        "Gene panels available for variants filtering", validators=[validators.Optional()]
+    )
+
+    gene_panels_matching = NonValidatingSelectMultipleField(
+        "Gene panels available for other variants matching (managed and causatives variants)",
+        validators=[validators.Optional()],
     )
 
     pheno_groups = NonValidatingSelectMultipleField("Custom phenotype groups", choices=hpo_tuples)
     cohorts = NonValidatingSelectMultipleField(
         "Available patient cohorts", validators=[validators.Optional()]
     )
+
     institutes = NonValidatingSelectMultipleField("Institutes to share cases with", choices=[])
 
     loqusdb_id = NonValidatingSelectField("LoqusDB id", choices=[])
 
     alamut_key = StringField("Alamut API key", validators=[validators.Optional()])
 
+    check_show_all_vars = BooleanField("Preselect 'Show also variants only present in unaffected'")
+
     submit_btn = SubmitField("Save settings")
 
 
@@ -135,6 +143,7 @@ class CaseFilterForm(FlaskForm):
     search_limit = IntegerField("Limit", [validators.Optional()], default=100)
     skip_assigned = BooleanField("Hide assigned")
     is_research = BooleanField("Research only")
+    validation_ordered = BooleanField("Validation pending")
     search = SubmitField(label="Search")
 
 
