@@ -15,12 +15,21 @@ from flask import (
     url_for,
 )
 from flask_login import current_user
+from pymongo import DESCENDING
 from werkzeug.datastructures import Headers
 
-from scout.constants import CASEDATA_HEADER, CLINVAR_HEADER, VERBS_ICONS_MAP, VERBS_MAP
+from scout.constants import (
+    ACMG_COMPLETE_MAP,
+    ACMG_MAP,
+    CALLERS,
+    CASEDATA_HEADER,
+    CLINVAR_HEADER,
+    VERBS_ICONS_MAP,
+    VERBS_MAP,
+)
 from scout.server.blueprints.variants.controllers import update_form_hgnc_symbols
 from scout.server.extensions import beacon, loqusdb, store
-from scout.server.utils import institute_and_case, jsonconverter, templated
+from scout.server.utils import institute_and_case, jsonconverter, templated, user_institutes
 
 from . import controllers
 from .forms import GeneVariantFiltersForm, InstituteForm, PhenoModelForm, PhenoSubPanelForm
@@ -67,11 +76,31 @@ def cases(institute_id):
     return controllers.cases(store, request, institute_id)
 
 
+@blueprint.route("/<institute_id>/verified")
+@templated("overview/verified.html")
+def verified(institute_id):
+    institute_obj = institute_and_case(store, institute_id)
+    verified_vars = controllers.verified_vars(institute_id)
+    verified_stats = controllers.verified_stats(institute_id, verified_vars)
+    return dict(
+        institute=institute_obj,
+        verified=verified_vars,
+        verified_stats=verified_stats,
+        acmg_map={key: ACMG_COMPLETE_MAP[value] for key, value in ACMG_MAP.items()},
+        callers=CALLERS,
+    )
+
+
 @blueprint.route("/<institute_id>/causatives")
 @templated("overview/causatives.html")
 def causatives(institute_id):
     institute_obj = institute_and_case(store, institute_id)
-    return controllers.causatives(institute_obj, request)
+    return dict(
+        institute=institute_obj,
+        causatives=controllers.causatives(institute_obj, request),
+        acmg_map={key: ACMG_COMPLETE_MAP[value] for key, value in ACMG_MAP.items()},
+        callers=CALLERS,
+    )
 
 
 @blueprint.route("/<institute_id>/filters", methods=["GET"])
@@ -112,7 +141,7 @@ def lock_filter(institute_id, filter_id):
 def gene_variants(institute_id):
     """Display a list of SNV variants."""
     page = int(request.form.get("page", 1))
-
+    result_size = None
     institute_obj = institute_and_case(store, institute_id)
 
     data = {}
@@ -133,22 +162,22 @@ def gene_variants(institute_id):
             flash("Provided gene symbols could not be used in variants' search", "warning")
             return redirect(request.referrer)
 
-        variants_query = store.gene_variants(
+        variants_query = store.build_variant_query(
             query=form.data,
-            institute_id=institute_id,
+            institute_ids=[inst["_id"] for inst in user_institutes(store, current_user)],
             category="snv",
             variant_type=variant_type,
-        )
+        )  # This is the actual query dictionary, not the cursor with results
 
-        result_size = store.count_gene_variants(
-            query=form.data,
-            institute_id=institute_id,
-            category="snv",
-            variant_type=variant_type,
-        )
-        data = controllers.gene_variants(store, variants_query, result_size, page)
+        results = store.variant_collection.find(variants_query).sort(
+            [("rank_score", DESCENDING)]
+        )  # query results
+        result_size = store.variant_collection.count_documents(variants_query)
+        data = controllers.gene_variants(
+            store, results, result_size, page
+        )  # decorated variant results, max 50 in a page
 
-    return dict(institute=institute_obj, form=form, page=page, **data)
+    return dict(institute=institute_obj, form=form, page=page, result_size=result_size, **data)
 
 
 # MOST OF THE CONTENT OF THIS ENDPOINT WILL BE REMOVED AND INCLUDED INTO THE BEACON EXTENSION UNDER SERVER/EXTENSIONS
