@@ -3,7 +3,8 @@ import os
 from base64 import b64encode
 from datetime import date
 
-from flask import current_app, flash, url_for
+import requests
+from flask import Markup, current_app, flash, url_for
 from flask_login import current_user
 
 from scout.constants import (
@@ -542,6 +543,66 @@ def observations(store, loqusdb, case_obj, variant_obj):
     return obs_data
 
 
+def str_variant_reviewer(
+    store,
+    case_obj,
+    variant_id,
+):
+    """Controller populating data and calling REViewer Service to fetch svg.
+    Args:
+        case_obj(dict)
+        variant_obj(dict)
+    Returns:
+        data(dict): {"individuals": list(dict())}}
+            individual dicts being dict with keys:
+                svg(str): image Markup text
+                display_name(str): display name
+                individual_id(str): internal id
+    """
+
+    variant_obj = store.variant(variant_id)
+
+    str_repid = variant_obj.get("str_repid")
+    print("str_variants_reviewer", str_repid)
+
+    url = current_app.config.get("SCOUT_REVIEWER_URL")
+
+    display_individuals = []
+    for ind in case_obj.get("individuals"):
+        display_individual = {
+            "display_name": ind.get("display_name"),
+            "individual_id": ind.get("individual_id"),
+        }
+
+        ind_reviewer = ind.get("reviewer")
+        if not url or not str_repid or not ind_reviewer:
+            display_individual["svg"] = Markup("<SVG></SVG>")
+            display_individuals.append(display_individual)
+            continue
+
+        srs_query_data = {
+            "reads": ind_reviewer.get("alignment"),
+            "reads_index": ind_reviewer.get("alignment_index"),
+            "vcf": ind_reviewer.get("vcf"),
+            "catalog": ind_reviewer.get("catalog"),
+            "locus": str_repid,
+        }
+
+        try:
+            resp = requests.post(url, json=srs_query_data)
+            display_individual["svg"] = Markup(resp.text)
+        except Exception as err:
+            flash(f"An error occurred while connecting to Scout-REViewer-Service: {err}")
+            display_individual["svg"] = Markup("<SVG></SVG>")
+
+        display_individuals.append(display_individual)
+
+    return {
+        "individuals": display_individuals,
+        "str_repid": str_repid,
+    }
+
+
 def variant_acmg(store, institute_id, case_name, variant_id):
     """Collect data relevant for rendering ACMG classification form.
 
@@ -600,7 +661,7 @@ def variant_acmg_post(store, institute_id, case_name, variant_id, user_email, cr
     return classification
 
 
-def build_clinvar_submission(store, request, institute_id, case_name, variant_id):
+def build_clinvar_submission(store, request, institute_id, case_name):
     """Add some variants to a ClinVar submission object or create a new ClinVar submission
 
     Args:
@@ -644,36 +705,32 @@ def build_clinvar_submission(store, request, institute_id, case_name, variant_id
     updated_submission = store.add_to_submission(open_submission["_id"], submission_objects)
 
 
-def clinvar_export(store, institute_id, case_name, variant_id):
+def clinvar_export(store, institute_obj, case_obj, variants):
     """Gather the required data for creating the clinvar submission form
 
     Args:
         store(scout.adapter.MongoAdapter)
-        institute_id(str): Institute ID
-        case_name(str): case ID
-        variant_id(str): variant._id
+        institute_obj(dict): scout.model.Institute
+        case_obj(dict): scout.model.Case
+        variants(list of strings): list of variant._ids
 
     Returns:
         data(dict): all the required data (case and variant level) to pre-fill in fields
                     in the clinvar submission form
 
     """
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     # If case diagnoses are a list of integers, convert into a list of dictionaries
     case_diagnoses = case_obj.get("diagnosis_phenotypes", [])
     if case_diagnoses and isinstance(case_diagnoses[0], int):
         case_obj = store.convert_diagnoses_format(case_obj)
-    pinned = [
-        store.variant(variant_id) or variant_id for variant_id in case_obj.get("suspects", [])
-    ]
-    variant_obj = store.variant(variant_id)
+    variant_objs = [store.variant(variant_id) or variant_id for variant_id in variants]
 
-    # gather missing transcript info from entrez (refseq id version)
-    for pinned_var in pinned:
+    # gather missing transcript info (refseq id version)
+    for var_obj in variant_objs:
         # Exclude variants that aren't loaded
-        if isinstance(pinned_var, str):
+        if isinstance(var_obj, str):
             continue
-        for gene in pinned_var.get("genes", []):
+        for gene in var_obj.get("genes", []):
             for transcript in gene.get("transcripts"):
                 refseq_id = transcript.get("refseq_id")
                 if not refseq_id:
@@ -684,7 +741,6 @@ def clinvar_export(store, institute_id, case_name, variant_id):
         today=str(date.today()),
         institute=institute_obj,
         case=case_obj,
-        variant=variant_obj,
-        pinned_vars=pinned,
+        pinned_vars=variant_objs,
         inheritance_models=CLINVAR_INHERITANCE_MODELS,
     )
