@@ -1,4 +1,5 @@
 import logging
+import re
 
 from flask import Blueprint, current_app, flash, jsonify, redirect, request, url_for
 from flask_login import current_user
@@ -7,7 +8,7 @@ from markupsafe import Markup
 from scout.constants import ACMG_CRITERIA, ACMG_MAP
 from scout.server.blueprints.variant.controllers import build_clinvar_submission, clinvar_export
 from scout.server.blueprints.variant.controllers import evaluation as evaluation_controller
-from scout.server.blueprints.variant.controllers import observations
+from scout.server.blueprints.variant.controllers import observations, str_variant_reviewer
 from scout.server.blueprints.variant.controllers import variant as variant_controller
 from scout.server.blueprints.variant.controllers import variant_acmg as acmg_controller
 from scout.server.blueprints.variant.controllers import variant_acmg_post
@@ -104,24 +105,25 @@ def sv_variant(institute_id, case_name, variant_id):
     return data
 
 
-@variant_bp.route("/<institute_id>/<case_name>/str/variants/<variant_id>")
-@templated("variant/str-variant.html")
-def str_variant(institute_id, case_name, variant_id):
-    """Display a specific STR variant."""
-    data = variant_controller(
-        store,
-        institute_id,
-        case_name,
-        variant_id,
-        add_other=False,
-        get_overlapping=False,
+@variant_bp.route("/<institute_id>/<case_name>/str/variant/<variant_id>", methods=["GET"])
+@templated("variant/str-variant-reviewer.html")
+def reviewer_aln(institute_id, case_name, variant_id):
+    """Display STR variant alignment using the REViewer service."""
+    if request.args.get("variant_type", "clinical") == "research":
+        variant_type = "research"
+    else:
+        variant_type = "clinical"
+
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    data = str_variant_reviewer(store, case_obj, variant_id)
+
+    return dict(
+        institute=institute_obj,
+        case=case_obj,
+        variant_type=variant_type,
+        format="html",
+        **data,
     )
-    if data is None:
-        flash("An error occurred while retrieving variant object", "danger")
-        return redirect(
-            url_for("variants.str_variants", institute_id=institute_id, case_name=case_name)
-        )
-    return data
 
 
 @variant_bp.route("/<institute_id>/<case_name>/<variant_id>/acmg", methods=["GET", "POST"])
@@ -299,17 +301,28 @@ def acmg():
     return jsonify(dict(classification=classification))
 
 
-@variant_bp.route("/<institute_id>/<case_name>/<variant_id>/clinvar", methods=["POST", "GET"])
+@variant_bp.route("/<institute_id>/<case_name>/clinvar", methods=["POST"])
 @templated("variant/clinvar.html")
-def clinvar(institute_id, case_name, variant_id):
-    """Build a clinVar submission form for a variant."""
+def clinvar_create(institute_id, case_name):
+    """Create a ClinVar submission document in database for one or more variants from a case."""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
 
-    if request.method == "GET":
-        data = clinvar_export(store, institute_id, case_name, variant_id)
+    if request.form.get(
+        "submit_pinned"
+    ):  # Request received from case page, contains IDs of vars to export to CLinVar
+        pinned_selected = request.form.getlist("clinvar_variant")
+        if not pinned_selected:
+            flash(
+                "Please select at least one pinned variant to include in ClinVar submission",
+                "warning",
+            )
+            return redirect(request.referrer)
+
+        data = clinvar_export(store, institute_obj, case_obj, pinned_selected)
         return data
 
-    # POST
-    build_clinvar_submission(store, request, institute_id, case_name, variant_id)
+    # Request received from ClinVar page, contains complete info to save in ClinVar submission document
+    build_clinvar_submission(store, request, institute_id, case_name)
 
     # Redirect to clinvar submissions handling page, to show the newest submission object
     return redirect(url_for("overview.clinvar_submissions", institute_id=institute_id))
