@@ -42,14 +42,14 @@ SPIDEX_CHOICES = [(term, term.replace("_", " ")) for term in SPIDEX_LEVELS]
 class NonValidatingSelectMultipleField(SelectMultipleField):
     """Necessary to skip validation of dynamic multiple selects in form"""
 
-    def pre_validate(self, form):
+    def pre_validate(self, _form):
         pass
 
 
 class NonValidatingSelectField(SelectField):
     """Necessary to skip validation of dynamic selects in form"""
 
-    def pre_validate(self, form):
+    def pre_validate(self, _form):
         pass
 
 
@@ -100,6 +100,7 @@ class VariantFiltersForm(FlaskForm):
     clinsig = NonValidatingSelectMultipleField("ClinVar CLINSIG", choices=CLINSIG_OPTIONS)
 
     gnomad_frequency = BetterDecimalField("gnomadAF", places=2, validators=[validators.Optional()])
+    local_obs = IntegerField("Local obs. (archive)")
 
     filters = NonValidatingSelectField(choices=[], validators=[validators.Optional()])
     filter_display_name = StringField(default="")
@@ -125,7 +126,7 @@ class VariantFiltersForm(FlaskForm):
     filter_variants = SubmitField(label="Filter variants")
     export = SubmitField(label="Filter and export")
 
-    show_unaffected = BooleanField("Show variants present only in unaffected", default=False)
+    show_unaffected = BooleanField("Show also variants present only in unaffected", default=False)
 
 
 class FiltersForm(VariantFiltersForm):
@@ -135,7 +136,6 @@ class FiltersForm(VariantFiltersForm):
 
     clinsig_confident_always_returned = BooleanField("CLINSIG Confident")
     spidex_human = SelectMultipleField("SPIDEX", choices=SPIDEX_CHOICES)
-    local_obs = IntegerField("Local obs. (archive)")
 
     clinical_filter = SubmitField(label="Clinical filter")
     clinvar_tag = BooleanField("ClinVar hits")
@@ -187,12 +187,6 @@ class CancerSvFiltersForm(SvFiltersForm):
 
     depth = IntegerField("Depth >", validators=[validators.Optional()])
     alt_count = IntegerField("Min alt count", validators=[validators.Optional()])
-    control_frequency = BetterDecimalField(
-        "Normal alt AF <", places=2, validators=[validators.Optional()]
-    )
-    tumor_frequency = BetterDecimalField(
-        "Tumor alt AF >", places=2, validators=[validators.Optional()]
-    )
 
 
 FILTERSFORMCLASS = {
