@@ -2,11 +2,9 @@
 import datetime
 import io
 import logging
-import os.path
-import shutil
 
 import pymongo
-from flask import Blueprint, flash, redirect, request, send_file, url_for
+from flask import Blueprint, flash, redirect, request, url_for
 from flask_login import current_user
 from markupsafe import Markup
 
@@ -18,13 +16,12 @@ from scout.constants import (
     SEVERE_SO_TERMS,
 )
 from scout.server.extensions import store
-from scout.server.utils import institute_and_case, templated, zip_dir_to_obj
+from scout.server.utils import institute_and_case, templated
 
 from . import controllers
 from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm
 
 LOG = logging.getLogger(__name__)
-
 variants_bp = Blueprint(
     "variants",
     __name__,
@@ -49,6 +46,7 @@ def variants(institute_id, case_name):
     page = int(Markup.escape(request.form.get("page", "1")))
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+
     variant_type = request.args.get("variant_type", "clinical")
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
@@ -80,6 +78,8 @@ def variants(institute_id, case_name):
         if form.gene_panels.data == [] and variant_type == "clinical":
             form.gene_panels.data = controllers.case_default_panels(case_obj)
 
+    controllers.populate_force_show_unaffected_vars(institute_obj, form)
+
     # populate filters dropdown
     available_filters = list(store.filters(institute_id, category))
     form.filters.choices = [
@@ -153,8 +153,10 @@ def variants(institute_id, case_name):
 @templated("variants/str-variants.html")
 def str_variants(institute_id, case_name):
     """Display a list of STR variants."""
+
     page = int(Markup.escape(request.form.get("page", "1")))
     variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
+
     category = "str"
 
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -177,6 +179,8 @@ def str_variants(institute_id, case_name):
         # set chromosome to all chromosomes
         form.chrom.data = request.args.get("chrom", "")
 
+    controllers.populate_force_show_unaffected_vars(institute_obj, form)
+
     # populate filters dropdown
     available_filters = list(store.filters(institute_id, category))
     form.filters.choices = [
@@ -212,6 +216,7 @@ def str_variants(institute_id, case_name):
     data = controllers.str_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
+
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -359,6 +364,8 @@ def cancer_variants(institute_id, case_name):
         if form.gene_panels.data == []:
             form.gene_panels.data = controllers.case_default_panels(case_obj)
 
+    controllers.populate_force_show_unaffected_vars(institute_obj, form)
+
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
@@ -536,39 +543,3 @@ def upload_panel(institute_id, case_name):
         url_for(".variants", institute_id=institute_id, case_name=case_name, **form.data),
         code=307,
     )
-
-
-@variants_bp.route("/verified", methods=["GET"])
-def download_verified():
-    """Download all verified variants for user's cases"""
-
-    user_obj = store.user(current_user.email)
-
-    user_institutes = (
-        [inst["_id"] for inst in store.institutes()]
-        if current_user.is_admin
-        else user_obj.get("institutes")
-    )
-    temp_excel_dir = os.path.join(variants_bp.static_folder, "verified_folder")
-    os.makedirs(temp_excel_dir, exist_ok=True)
-
-    if controllers.verified_excel_file(store, user_institutes, temp_excel_dir):
-        data = zip_dir_to_obj(temp_excel_dir)
-
-        # remove temp folder with excel files in it
-        shutil.rmtree(temp_excel_dir)
-
-        today = datetime.datetime.now().strftime("%Y-%m-%d")
-        return send_file(
-            data,
-            mimetype="application/zip",
-            as_attachment=True,
-            download_name="_".join(["scout", "verified_variants", today]) + ".zip",
-            cache_timeout=0,
-        )
-
-    # remove temp folder with excel files in it
-    shutil.rmtree(temp_excel_dir)
-
-    flash("No verified variants could be exported for user's institutes", "warning")
-    return redirect(request.referrer)
