@@ -69,21 +69,32 @@ ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
 #    "loqus_api" : {"api_url": "http://127.0.0.1:9000"},
 # }
 
+# Connection details for Scout REViewer service
+# URL
+# SCOUT_REVIEWER_URL = "http://127.0.0.1:8000/reviewer"
+
 #
 # Cloud IGV tracks can be configured here to allow users to enable them on their IGV views.
+# A number of publicly-available tracks can be found here: https://trackhubregistry.org/
 # CLOUD_IGV_TRACKS = [
 #    {
-#        "name": "custom_public_bucket",
+#        "name": "public_tracks",
 #        "access": "public",
 #        "tracks": [
 #            {
-#                "name": "dbVar Pathogenic or Likely Pathogenic",
-#                "type": "variant",
-#                "format": "vcf",
+#                "name": "dbVar common SVs (global)",
+#                "type": "annotation",
+#                "format": "bigbed",
 #                "build": "37",
-#                "url": "https://s3-eu-west-1.amazonaws.com/pfigshare-u-files/25777457/GRCh37.variant_call.clinical.pathogenic_or_likely_pathogenic.vcf.gz",
-#                "indexURL": "https://s3-eu-west-1.amazonaws.com/pfigshare-u-files/25777460/GRCh37.variant_call.clinical.pathogenic_or_likely_pathogenic.vcf.gz.tbi",
-#            }
+#                "url": "https://ftp.ncbi.nlm.nih.gov/pub/dbVar/sandbox/dbvarhubtest/hg19/common_global.bb",
+#            },
+#            {
+#                "name": "dbVar common SVs (global)",
+#                "type": "annotation",
+#                "format": "bigbed",
+#                "build": "38",
+#                "url": "https://ftp.ncbi.nlm.nih.gov/pub/dbVar/sandbox/dbvarhubtest/hg38/common_global.bb",
+#            },
 #        ],
 #    },
 # ]
@@ -92,12 +103,13 @@ ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
 REPORT_LANGUAGE = "en"
 ACCEPT_LANGUAGES = ["en", "sv"]
 
-# TICKET_SYSTEM_EMAIL = "support@test_service.com"
-
 # FEATURE FLAGS
 SHOW_CAUSATIVES = True
 SHOW_OBSERVED_VARIANT_ARCHIVE = True
 HIDE_ALAMUT_LINK = True
+
+# URL of a general web page where users can place orders for analyses or reruns
+RERUN_URL = "https://clinical.scilifelab.se/"
 # Display case rerun monitoring toggle
 RERUN_MONITOR = True
 
