@@ -586,7 +586,7 @@ def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     assert res["status"] == "archived"
 
     # request rerun for test case
-    adapter.request_rerun(institute_obj, res, user_obj, "blank")
+    adapter.update_rerun_status(institute_obj, res, user_obj, "blank")
     res = adapter.case(case_obj["_id"])
     # THEN rerun_requested is flagged
     assert res["rerun_requested"] is True
@@ -596,14 +596,15 @@ def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     # Make sure user becomes assignee of the case
     assert user_obj["email"] in res["assignees"]
 
+    # WHEN rerun is reset using the same method:
     # And that a new rerun request triggers an error:
-    with pytest.raises(ValueError):
-        adapter.request_rerun(institute_obj, res, user_obj, "blank")
+    adapter.update_rerun_status(institute_obj, res, user_obj, "blank")
 
-    # and WHEN updating the case again
+    # THEN case rerun status should be reset
     res = adapter.update_case(case_obj)
+    assert res["rerun_requested"] is False
 
-    # THEN it is inactivated
+    # AND case it is inactivated
     res = adapter.case(case_obj["_id"])
     assert res["status"] == "inactive"
 
@@ -742,6 +743,20 @@ def test_get_cases_solved_since(real_adapter, case_obj, user_obj, institute_obj,
     assert len([case for case in adapter.cases(finished=True, within_days=1)]) == 1
 
 
+def test_verification_missing_cases(real_adapter, case_obj, user_obj, institute_obj, variant_obj):
+    """Test cases adapter function to retrieve case _ids with Sanger ordered validations (not verified)"""
+    adapter = real_adapter
+    adapter.case_collection.insert_one(case_obj)
+
+    # Order Sanger verification for one variant
+    adapter.variant_collection.insert_one(variant_obj)
+    adapter.order_verification(institute_obj, case_obj, user_obj, "link", variant_obj)
+
+    # WHEN querying for cases with Sanger validation pending
+    # THEN one case is found
+    assert len(adapter.verification_missing_cases(institute_obj["_id"])) == 1
+
+
 def test_keep_manual_rank_tag_after_reupload(
     adapter, case_obj, variant_obj, user_obj, institute_obj
 ):
