@@ -7,7 +7,7 @@ from flask import current_app, json, url_for
 
 from scout.demo import delivery_report_path
 from scout.server.blueprints.cases.views import parse_raw_gene_ids, parse_raw_gene_symbols
-from scout.server.extensions import mail, store
+from scout.server.extensions import store
 
 TEST_TOKEN = "test_token"
 
@@ -193,47 +193,6 @@ def test_reset_research(app, institute_obj, case_obj, mocker, mock_redirect):
         assert store.event_collection.find_one({"verb": "reset_research"})
 
 
-def test_rerun(app, institute_obj, case_obj, monkeypatch, mocker, mock_redirect):
-    """test case rerun function"""
-
-    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
-
-    # GIVEN an initialized app
-    # GIVEN a valid user
-
-    def send_email(*args, **kwargs):
-        return True
-
-    monkeypatch.setattr(mail, "send", send_email)
-
-    # GIVEN a test case without rerun pending
-    test_case = store.case_collection.find_one()
-    assert test_case.get("rerun_requested") is False
-
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # WHEN rerun request is sent
-        resp = client.post(
-            url_for(
-                "cases.rerun",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-            ),
-        )
-        assert resp.status_code == 302
-        updated_case = store.case_collection.find_one()
-
-        # THEN the case should be updated
-        assert updated_case["rerun_requested"] is True
-        rerun_event = store.event_collection.find_one()
-
-        # AND a rerun event should be created
-        assert rerun_event.get("verb") == "rerun"
-
-
 def test_parse_raw_gene_symbols(app):
     """Test parse gene symbols"""
 
