@@ -14,6 +14,37 @@ TEST_SUBPANEL = dict(
 )
 
 
+def test_gene_variants(app, user_obj, institute_obj):
+    """Test the page that returns all SNPs and INDELs given a gene provided by user"""
+
+    # GIVEN a form filled in by the user
+    form_data = {
+        "hgnc_symbols": "POT1",
+        "variant_type": [],  # This will set variant type to ["clinical"] in the endpoint function
+        "category": "snv",
+        "rank_score": 5,
+    }
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # WITH a logged user
+        client.get(url_for("auto_login"))
+
+        # WHEN form is submitted by POST request
+        resp = client.post(
+            url_for(
+                "overview.gene_variants",
+                institute_id=institute_obj["internal_id"],
+            ),
+            data=form_data,
+        )
+        # THEN it should return a valid page
+        assert resp.status_code == 200
+
+        # containing the expected results
+        assert "POT1" in str(resp.data)
+
+
 def test_events_timeline(app, user_obj, institute_obj, case_obj):
     """Test the wiew that returns the last 100 groups of events for a user"""
 
@@ -655,6 +686,31 @@ def test_cases_similar_phenotype_query(app, case_obj, institute_obj, test_hpo_te
         assert case_obj["display_name"] in str(resp.data)
 
 
+def test_verified(app, institute_obj, case_obj, user_obj, variant_obj):
+    """Test the endpoint that returns the list of verified variants for an institute"""
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        client.get(url_for("auto_login"))
+
+        # GIVEN a verified variant:
+        store.validate(
+            institute=institute_obj,
+            case=case_obj,
+            user=user_obj,
+            link="link",
+            variant=variant_obj,
+            validate_type="False positive",
+        )
+
+        # WHEN accessing the verified variants page
+        resp = client.get(url_for("overview.verified", institute_id=institute_obj["internal_id"]))
+        assert resp.status_code == 200
+
+        # The variant should be found:
+        assert variant_obj["_id"] in str(resp.data)
+
+
 def test_causatives(app, user_obj, institute_obj, case_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
