@@ -2,7 +2,14 @@
 
 from flask import url_for
 
-from scout.server.links import add_gene_links, alamut_link, cbioportal, mycancergenome, snp_links
+from scout.server.links import (
+    add_gene_links,
+    alamut_link,
+    cbioportal,
+    ckb_gene,
+    mycancergenome,
+    snp_links,
+)
 
 
 def test_alamut_link(app, institute_obj, variant_obj):
@@ -83,6 +90,13 @@ def test_mycancergenome_link():
     assert link is not None
 
 
+def test_ckb_link():
+    """Test building the link for The Clinical KnowledgeBase (Jackson Lab)"""
+    entrez_id = 7015
+    link = ckb_gene(entrez_id)
+    assert link is not None
+
+
 def test_snp_links():
     """Test building the links for the SNP ids of a variant"""
     # GIVEN a variant with multiple SNP IDs
